pub trait KeyValueStoreError:
Error
+ From<Error>
+ Debug
+ Send
+ Sync
+ 'static {
const BACKEND: &'static str;
// Provided method
fn must_reload_view(&self) -> bool { ... }
}Expand description
The error type for the key-value stores.
Required Associated Constants
Provided Methods
Sourcefn must_reload_view(&self) -> bool
fn must_reload_view(&self) -> bool
Returns true if this error may have left storage in an undetermined state,
so the view must be reloaded before being used again.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl KeyValueStoreError for ViewContainerError
Available on with_testing only.
impl KeyValueStoreError for ViewContainerError
Available on
with_testing only.