Trait KeyValueStoreError

pub trait KeyValueStoreError:
    Error
    + From<Error>
    + Debug
    + Send
    + Sync
    + 'static {
    const BACKEND: &'static str;

    // Provided method
    fn must_reload_view(&self) -> bool { ... }
}
The error type for the key-value stores.

Required Associated Constants

const BACKEND: &'static str

The name of the backend.

Provided Methods

fn must_reload_view(&self) -> bool

Returns true if this error represents a journal resolution failure, which may leave storage in an inconsistent state requiring a view reload.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl KeyValueStoreError for DynamoDbStoreInternalError

Source

const BACKEND: &'static str = "dynamo_db"

Source

impl KeyValueStoreError for MemoryStoreError

Source

const BACKEND: &'static str = "memory"

Source

impl KeyValueStoreError for RocksDbStoreInternalError

Source

const BACKEND: &'static str = "rocks_db"

Source

impl KeyValueStoreError for ScyllaDbStoreInternalError

Source

const BACKEND: &'static str = "scylla_db"

Source

impl KeyValueStoreError for ViewContainerError

Source

const BACKEND: &'static str = "view_container"

Source

impl KeyValueStoreError for InactiveStoreError

Source

const BACKEND: &'static str = "inactive"

Source

impl<E1, E2> KeyValueStoreError for DualStoreError<E1, E2>

Source

const BACKEND: &'static str = "dual_store"

Source

impl<E: KeyValueStoreError + 'static> KeyValueStoreError for JournalingError<E>

Source

const BACKEND: &'static str = "journaling"

Source

impl<E: KeyValueStoreError + 'static> KeyValueStoreError for ValueSplittingError<E>

Source

const BACKEND: &'static str = "value splitting"