pub trait KeyValueStoreError:
Error
+ From<Error>
+ Debug
+ Send
+ Sync
+ 'static {
const BACKEND: &'static str;
// Provided method
fn must_reload_view(&self) -> bool { ... }
}Expand description
The error type for the key-value stores.
Required Associated Constants
Provided Methods
Sourcefn must_reload_view(&self) -> bool
fn must_reload_view(&self) -> bool
Returns true if this error represents a journal resolution failure,
which may leave storage in an inconsistent state requiring a view reload.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.